function Display_mag
%-------------------------------------------------------------------------
%Function to display mag data collected with a walking mag and
% a base station mag
% Greg Nieuwenhuis, February 2009


% Settings:
%   uncor_high/ uncor_low - sets the limits for plotting the data
%   method   -  change to set how griddata grids the data 
%------------------------------------------------------------------------

close all
clear all

uncor_high=60000; % cutoff factors for the uncorrected data
uncor_low=52500;

method='v4'; % can be 'linear', 'cubic', 'nearest', 'v4'


base_dat=load('base.txt'); %first column time
                          %second column nT

walk_dat=load('Walk.txt');  % First column time
                              % second column latitude
                              % third column longitude
                              % 4th column nT

gps=load('gps_paths_edit.txt');% First column time
                              % second column latitude
                              % third column longitude
                              % 4th column N/A nT
                             

% Change time from HHMMSS to sec
base_str(:,:)=num2str(base_dat(:,1));
walk_str(:,:)=num2str(walk_dat(:,1));

len_base=length(base_str(:,1));
len_walk=length(walk_str(:,1));

for i=1:len_base
    
    base_sec(i,1)=str2num(base_str(i,5:6))+(str2num(base_str(i,3:4))*60)+(str2num(base_str(i,1:2))*60*60);
    
end

clear i

for i=1:len_walk
    
    walk_sec(i,1)=str2num(walk_str(i,5:6))+(str2num(walk_str(i,3:4))*60)+(str2num(walk_str(i,1:2))*60*60);
    
end

clear i
temp1(:,1)=base_sec(:,1);
temp2(:,1)=walk_sec(:,1);
temp1(:,2)=base_dat(:,2);
for i=2:4
    temp2(:,i)=walk_dat(:,i);
end

clear base_dat walk_dat

base_dat=temp1;
walk_dat=temp2;

clear temp1 temp2 i

% Change LAT/LONG into UTM
[walk_dat(:,3),walk_dat(:,2),zone]=deg2utm(walk_dat(:,2), walk_dat(:,3));
[gps(:,3),gps(:,2),zone]=deg2utm(gps(:,2),gps(:,3));


% Make equal spaced vectors for gridding
X(1,:)=[min(walk_dat(:,3)):3:max(walk_dat(:,3))];

Y(:,1)=[min(walk_dat(:,2)):3:max(walk_dat(:,2))];

[XI,YI,ZI]=griddata(walk_dat(:,3),walk_dat(:,2),walk_dat(:,4),X,Y,method);
figure

%plot the grid of uncorrected data from the walking mag
pcolor(X,Y,ZI);
caxis([uncor_low uncor_high]);
shading interp
title('Uncorrected Total Field (nT)')
xlabel('Eastings (m)')
ylabel('Northings (m)')
hold on;
plot(walk_dat(:,3),walk_dat(:,2),'r+')
colorbar
hold on
plot(gps(:,3),gps(:,2))
axis equal


% %PLot the original and corrected time series in minutes
% base_dat(:,1)=base_dat(:,1)./60;
% walk_dat(:,1)=walk_dat(:,1)./60;
% 
% figure
% subplot(2,1,1)
% plot(base_dat(:,1),base_dat(:,2),'r')
% v=axis;
% title('Base Mag')
% ylabel('Magnetic Field (nT)')
% 
% subplot(2,1,2)
% plot(walk_dat(:,1),walk_dat(:,4),'b')
% v2=axis;
% v=[v(1) v(2) v2(3) v2(4)];
% axis(v);
% title('Walking Mag')
% ylabel('Magnetic Field (nT)')
% xlabel('UTC Time (min)')

